﻿<%@ Control Language="C#" ClassName="TaxonomyMenu" %>

<script runat="server">

    StringBuilder sb = new StringBuilder();

    private long _MenuID = 0;
    /// <summary>
    /// Id of the taxonomy node to start at
    /// </summary>
    public long MenuID
    {
        get
        {
            return _MenuID;
        }
        set
        {
            _MenuID = value;
        }
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        //not that permissioning will not take place unless you come up with a new method to check permissions as taxonomy node viewing is public
        
        //make sure menu id is not root taxonomy node
        if (_MenuID > 0)
        {
            //new instance of the taxonomy manager
            Ektron.Cms.Framework.Organization.TaxonomyManager tManager = new Ektron.Cms.Framework.Organization.TaxonomyManager();
            //cache the taxonomy by id and language
            string cacheKey = "TaxMenuCache:ID" + _MenuID + "Lang:" + tManager.ContentLanguage;
            //check for cache
            if (Cache[cacheKey] != null)
            {
                //output cached value
                menuData.Text = (string)Cache[cacheKey];
            }
            else
            {
                //use gettree to retrieve all subnodes. If you need to only display a few levels, use css or jquery to remove other nodes or modify the code.
                var taxMenu = tManager.GetTree(_MenuID, -1, false, new Ektron.Cms.PagingInfo(50), Ektron.Cms.Common.EkEnumeration.TaxonomyType.Content, Ektron.Cms.Common.EkEnumeration.TaxonomyItemsSortOrder.taxonomy_item_display_order);
                //generate the menu html
                BuildMenu(taxMenu.Taxonomy.ToList());
                //output cached value 
                menuData.Text = sb.ToString();
                //cache the menu html
                Cache.Insert(cacheKey, sb.ToString(), null, DateTime.Now.AddHours(12), System.Web.Caching.Cache.NoSlidingExpiration);
            }
        }
        else
        {
            //output message if menu id is less than 0
            menuData.Text = "<li>ID must be greater than 0</li>";
        }
    }

    private void BuildMenu(List<Ektron.Cms.TaxonomyData> tData)
    {
        foreach (var item in tData)
        {
            if (item.CategoryUrl != "" && !item.CategoryUrl.ToLower().StartsWith("http"))
            {
                //make sure we have a leading /
                item.CategoryUrl = "/" + item.CategoryUrl.TrimStart('/');
            }
            if (item.HasChildren)
            {
                if (item.Level <= 2)
                {
                    //item is off of the root
                    sb.Append("<li class='root'>");
                    sb.Append("<a class='dropdown-toggle navitemlink' data-toggle='dropdown' href='" + item.CategoryUrl + "'>" + item.Name + "<b class='caret'></b></a>");
                }
                else
                {
                    //item is deeper inside the menu
                    sb.Append("<li class='dropdown-submenu'>");
                    sb.Append("<a class='dropdown-toggle navitemlink' data-toggle='dropdown' href='" + item.CategoryUrl + "'>" + item.Name + "</a>");
                }
                //build a new ul li structure inside the parent if nodes exist
                sb.Append("<ul class='dropdown-menu'>");
                if (item.Taxonomy != null)
                {
                    if (item.Taxonomy.Length > 0)
                    {
                        BuildMenu(item.Taxonomy.ToList());
                    }
                }
                //close out the tags
                sb.Append("</ul></li>");
            }
            else
            {
                //single level item
                sb.Append("<li><a class='navitemlink' href='" + item.CategoryUrl + "'>" + item.Name + "</a></li>");
            }
        }
    }
    
</script>
<%--Styling from http://jsfiddle.net/e2xEL/2/--%>
<nav class="navbar navbar-default" role="navigation">
    <!-- Brand and toggle get grouped for better mobile display -->
    <div class="navbar-header">
        <button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-ex1-collapse">
            <span class="sr-only">Toggle navigation</span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
        </button>
    </div>
    <!-- Collect the nav links, forms, and other content for toggling -->
    <div class="collapse navbar-collapse navbar-ex1-collapse">
        <ul class="nav navbar-nav taxNavigation">
            <asp:Literal ID="menuData" runat="server"></asp:Literal>
        </ul>
    </div>
    <!-- /.navbar-collapse -->
</nav>
<style type="text/css">
    .dropdown-submenu > .dropdown-menu {
            top: 0;
            left: 100%;
            margin-top: -6px;
            margin-left: -1px;
            -webkit-border-radius: 0 6px 6px 6px;
            -moz-border-radius: 0 6px 6px 6px;
            border-radius: 0 6px 6px 6px;
        }

        .dropdown-submenu:hover > .dropdown-menu {
            display: block;
        }
    
    @media (min-width: 768px) {
        .dropdown-submenu {
            position: relative;
        }

            .dropdown-submenu > .dropdown-menu {
                top: 0;
                left: 100%;
                margin-top: -6px;
                margin-left: -1px;
                -webkit-border-radius: 0 6px 6px 6px;
                -moz-border-radius: 0 6px 6px 6px;
                border-radius: 0 6px 6px 6px;
            }

            .dropdown-submenu:hover > .dropdown-menu {
                display: block;
            }

            .dropdown-submenu > a:after {
                display: block;
                content: " ";
                float: right;
                width: 0;
                height: 0;
                border-color: transparent;
                border-style: solid;
                border-width: 5px 0 5px 5px;
                border-left-color: #cccccc;
                margin-top: 5px;
                margin-right: -10px;
            }

            .dropdown-submenu:hover > a:after {
                border-left-color: #ffffff;
            }

            .dropdown-submenu .pull-left {
                float: none;
            }

                .dropdown-submenu.pull-left > .dropdown-menu {
                    left: -100%;
                    margin-left: 10px;
                    -webkit-border-radius: 6px 0 6px 6px;
                    -moz-border-radius: 6px 0 6px 6px;
                    border-radius: 6px 0 6px 6px;
                }

        .root:hover > .dropdown-menu {
            display: block;
        }
    }

</style>
<link href="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/css/bootstrap.min.css" rel="stylesheet">
<script src="https://code.jquery.com/jquery-2.1.1.min.js"></script>
<script src="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/js/bootstrap.min.js"></script>
<script type="text/javascript">
    $(document).ready(function () {
        $('.navbar-brand').html(window.location.host);
        $('.taxNavigation ul li a').each(function () {
            if ($(this).attr('href').toString().toLowerCase() == window.location.pathname.toString().toLowerCase()) {
                $(this).parents('li').each(function () {
                    $(this).addClass('active');
                });

            }
        });
    });
</script>

